*     ... THIS IS THE ENERGY THRESHOLD FUNCTION OF ELECTRONS
*     ... IN A SHOWER OBTAINED FROM A PAPER OF A.M.HILLAS
*     ... J.Phys.G.:Nucl.Phys., 8 (1982) 1461-1473
*     ... INPUT: S  (shower age)
*                ET (electron energy in eV)
*     ... OUTPUT: FRACTION OF ELECTRONS WITH ENERGY 
*                 ABOVE ET AT A GIVEN S
*     ... DATE: 29.05.2002
*     ... AUTHOR: D.V.NAUMOV      
      REAL FUNCTION ENERGY_THRESHOLD_HILLAS(S,ET)
      IMPLICIT NONE
#include "shower.inc"
#include "event.inc"
      REAL S,ET,f,E,E0
*
      E = ET                    
      IF(S.GE.0.4) E0 = 44. - 17*(S-1.46) ! MeV
      IF(S.LT.0.4) E0 = 26.               ! MeV
      f = ((0.89*E0-1.2)/(E+E0))**S/(1.+1.e-4*S*E)**2
      IF(S.LT.0) THEN
         ENERGY_THRESHOLD_HILLAS = 0.
      ELSE
         ENERGY_THRESHOLD_HILLAS = f
      ENDIF
      END

